import 'package:flutter/material.dart';
import 'package:fluttertoast/fluttertoast.dart';
import 'package:get/get.dart';
import 'package:insuideindoor/http/services.dart';
import 'package:insuideindoor/kkk/loading.dart';
import 'package:insuideindoor/models/poi_model.dart';
// import 'package:mapbox_gl_example/http/services.dart';
// import 'package:mapbox_gl_example/kkk/loading.dart';
// import 'package:mapbox_gl_example/kkk/my_home.dart';
// import 'package:mapbox_gl_example/models/poi_model.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:flutter_dotenv/flutter_dotenv.dart';
import 'package:mapbox_gl/mapbox_gl.dart';

import 'my_home.dart';

class FinalHome extends StatefulWidget {
  const FinalHome({Key? key}) : super(key: key);

  @override
  State<FinalHome> createState() => _FinalHomeState();
}

class _FinalHomeState extends State<FinalHome> {
  GetPoi? poiPoints;
  List<LatLng> poisList = [];
  List<String> poisSubCat = [];
  bool isLoading = true;
  int? loopCounter;
  String? kamalStyle;
  late CameraPosition _initialCameraPosition;
  late MapboxMapController controller;
  @override
  void initState() {
    super.initState();
    isLoading = true;
    sharedLatLng().then((value) {
      setState(() {
        _initialCameraPosition =
            CameraPosition(target: value, zoom: 17, tilt: 30.0);
        isLoading = false;
      });
    });

    sharedStyleString().then((value) {
      setState(() {
        kamalStyle = value;
        isLoading = false;
      });
    });
    fetchPois();
  }

  Future<LatLng> sharedLatLng() async {
    setState(() {
      isLoading = true;
    });
    final SharedPreferences sharedPreferences =
        await SharedPreferences.getInstance();
    double latt = sharedPreferences.getDouble('lat') ?? 19.093099;
    double longg = sharedPreferences.getDouble('long') ?? 72.856952;
    print("I'm Lat ${sharedPreferences.getDouble('lat')}");
    print("I'm Long ${sharedPreferences.getDouble('long')}");
    print("RETURNING THIS FROM SHARED PREFS ${LatLng(latt, longg)}");

    return LatLng(latt, longg);
  }

  Future<String> sharedStyleString() async {
    setState(() {
      isLoading = true;
    });
    final SharedPreferences sharedPreferences =
        await SharedPreferences.getInstance();
    String styleString = sharedPreferences.getString('styleString') ??
        'mapbox://styles/merrillgonsalves/cl5ez27io005p14rz5aqp8234';
    print("I'm style string ${sharedPreferences.getString('styleString')}");
    return styleString;
  }

  void _onMapCreated(MapboxMapController mapboxMapController) {
    controller = mapboxMapController;
  }

  fetchPois() async {
    poiPoints = await InternetService().getPOI().then((value) {
      loopCounter = value!.data!.length;
      poisList.clear();
      poisSubCat.clear();
      for (int a = 1; a <= loopCounter!; a++) {
        // print("latlng ${a - 1} is : ${value.data![a - 1].lat}");
        poisList.insert(
            a - 1, LatLng(value.data![a - 1].lat!, value.data![a - 1].lng!));

        poisSubCat.insert(
            a - 1, value.data?[a - 1].poiMultilingual!.en!.name ?? "Test");
      }
      return null;
    });
    if (!mounted) return;
    setState(() {
      isLoading = false;
    });
  }

  tappedaFunction(Symbol symbol) {
    print("print $symbol");

    Fluttertoast.showToast(
      msg: 'Tapped on POI',
    );
  }

  void addSymbol(MapboxMapController mapBoxController) {
    for (int a = 0; a < loopCounter!; a++) {
      // print("kkkkkk ${poisList[a]}");
      mapBoxController.addSymbol(
        SymbolOptions(
            geometry: poisList[a],
            iconImage: "assets/symbols/neww.png",
            iconSize: 0.5,
            textField: poisSubCat[a],
            textSize: 15,
            iconOffset: const Offset(0, -50)),
      );
    }
    mapBoxController.onSymbolTapped.add(tappedaFunction);

    //SHOWING CURRENT USER LOCATION ON MAP
    mapBoxController.addSymbol(
      SymbolOptions(
        geometry: LatLng(19.093099, 72.856952),
        // geometry: convertToLatLng(),
        iconImage: "assets/symbols/Oval.png",
        iconSize: 3,
      ),
    );
    mapBoxController.onSymbolTapped.add(tappedaFunction);
  }

  Widget build(BuildContext context) {
    double myHeight = MediaQuery.of(context).size.height / 3.8;
    double myBigHeight = MediaQuery.of(context).size.height - myHeight - 100;
    double width = MediaQuery.of(context).size.width;
    double height = MediaQuery.of(context).size.height;
    double btnPadding = 10.0;
    double btnSize = 25.0;
    double fontSize = 16.0;
    return Scaffold(
      body: SafeArea(
          child: Container(
        width: width,
        height: height,
        child: Stack(
          children: [
            SizedBox(
              child: isLoading
                  ? Center(
                      child: Column(
                        mainAxisAlignment: MainAxisAlignment.center,
                        children: [
                          CircularProgressIndicator(),
                          SizedBox(
                            height: 20,
                          ),
                          Text("Loading POI's & IA Location")
                        ],
                      ),
                    )
                  : Column(
                      children: [
                        Stack(
                          alignment: Alignment.bottomCenter,
                          children: [
                            Container(
                              height: myBigHeight,
                              child: MapboxMap(
                                tiltGesturesEnabled: true,
                                accessToken: dotenv.env['MAPBOX_ACCESS_TOKEN'],
                                initialCameraPosition: _initialCameraPosition,
                                onMapCreated: _onMapCreated,
                                trackCameraPosition: true,
                                onCameraTrackingChanged: (mode) {
                                  // print("mode.name ${mode}");
                                  // print("mode.name ${mode.name}");
                                },

                                onStyleLoadedCallback: () =>
                                    addSymbol(controller),
                                // myLocationEnabled: true,
                                myLocationTrackingMode:
                                    MyLocationTrackingMode.TrackingGPS,
                                // minMaxZoomPreference:
                                //     const MinMaxZoomPreference(14, 17),
                                annotationOrder: [AnnotationType.symbol],
                                styleString: kamalStyle,
                              ),
                            ),
                            Container(
                              margin: EdgeInsets.only(left: 20, right: 20),
                              padding: EdgeInsets.only(bottom: 10),
                              child: Row(
                                crossAxisAlignment: CrossAxisAlignment.end,
                                mainAxisAlignment:
                                    MainAxisAlignment.spaceBetween,
                                children: [
                                  GestureDetector(
                                    onTap: () {
                                      // controller.animateCamera(
                                      //     CameraUpdate.newCameraPosition(
                                      //         CameraPosition(
                                      //             target: LatLng(
                                      //                 19.093099, 72.856952))));
                                      Get.to(const MyHome(
                                          data:
                                              "26.828943333333335,75.80561666666667"));
                                    },
                                    child: Container(
                                      padding: EdgeInsets.all(btnPadding),
                                      decoration: BoxDecoration(
                                          color: Colors.white,
                                          borderRadius:
                                              BorderRadius.circular(10)),
                                      child: Icon(
                                        Icons.gps_fixed,
                                        size: btnSize,
                                      ),
                                    ),
                                  ),
                                  Column(
                                    children: [
                                      GestureDetector(
                                        onTap: () {
                                          showModalBottomSheet<void>(
                                            context: context,
                                            builder: (BuildContext context) {
                                              return Container(
                                                decoration: const BoxDecoration(
                                                    color: Colors.white,
                                                    borderRadius:
                                                        BorderRadius.only(
                                                            topLeft: Radius
                                                                .circular(50),
                                                            topRight:
                                                                Radius.circular(
                                                                    50))),
                                                child: Padding(
                                                  padding: const EdgeInsets.all(
                                                      10.0),
                                                  child: SingleChildScrollView(
                                                    child: Column(
                                                      crossAxisAlignment:
                                                          CrossAxisAlignment
                                                              .start,
                                                      children: [
                                                        TextButton(
                                                            onPressed:
                                                                () async {
                                                              final SharedPreferences
                                                                  sharedPreferences =
                                                                  await SharedPreferences
                                                                      .getInstance();
                                                              sharedPreferences
                                                                  .setDouble(
                                                                      'lat',
                                                                      19.093099);
                                                              sharedPreferences
                                                                  .setDouble(
                                                                      'long',
                                                                      72.856952);
                                                              sharedPreferences
                                                                  .setString(
                                                                      'styleString',
                                                                      'mapbox://styles/merrillgonsalves/cl5ez27io005p14rz5aqp8234');
                                                              Get.off(
                                                                  Loading());
                                                              // Navigator.pop(
                                                              //     context);
                                                              print(
                                                                  "TAPPED IN LEVEL 0");
                                                              controller
                                                                  .dispose();
                                                            },
                                                            child: Text(
                                                                "Level 0")),
                                                        TextButton(
                                                            onPressed:
                                                                () async {
                                                              final SharedPreferences
                                                                  sharedPreferences =
                                                                  await SharedPreferences
                                                                      .getInstance();
                                                              sharedPreferences
                                                                  .setDouble(
                                                                      'lat',
                                                                      19.092141);
                                                              sharedPreferences
                                                                  .setDouble(
                                                                      'long',
                                                                      72.855159);
                                                              sharedPreferences
                                                                  .setString(
                                                                      'styleString',
                                                                      'mapbox://styles/merrillgonsalves/cl5ez2lht002214s0ow0ghr8z');
                                                              Get.off(
                                                                  Loading());
                                                              // Navigator.pop(
                                                              //     context);
                                                              controller
                                                                  .dispose();
                                                              print(
                                                                  "TAPPED IN LEVEL 1");
                                                            },
                                                            child: Text(
                                                                "Level 1")),
                                                        TextButton(
                                                            onPressed:
                                                                () async {
                                                              final SharedPreferences
                                                                  sharedPreferences =
                                                                  await SharedPreferences
                                                                      .getInstance();
                                                              sharedPreferences
                                                                  .setDouble(
                                                                      'lat',
                                                                      19.092067);
                                                              sharedPreferences
                                                                  .setDouble(
                                                                      'long',
                                                                      72.853808);
                                                              sharedPreferences
                                                                  .setString(
                                                                      'styleString',
                                                                      'mapbox://styles/merrillgonsalves/cl5l2hq6w001o15nxfhzighuw');
                                                              Get.off(
                                                                  Loading());
                                                              controller
                                                                  .dispose();
                                                              // Navigator.pop(
                                                              //     context);
                                                              print(
                                                                  "TAPPED IN LEVEL 2");
                                                            },
                                                            child: Text(
                                                                "Level 2")),
                                                      ],
                                                    ),
                                                  ),
                                                ),
                                              );
                                            },
                                          );
                                        },
                                        child: Container(
                                          padding: EdgeInsets.all(btnPadding),
                                          decoration: BoxDecoration(
                                              color: Colors.white,
                                              borderRadius: BorderRadius.only(
                                                  topLeft: Radius.circular(7),
                                                  topRight:
                                                      Radius.circular(7))),
                                          child:
                                              Icon(Icons.layers, size: btnSize),
                                        ),
                                      ),
                                      SizedBox(
                                        height: 1,
                                      ),
                                      GestureDetector(
                                        child: Container(
                                          padding: EdgeInsets.all(btnPadding),
                                          decoration: BoxDecoration(
                                            color: Colors.white,
                                            // borderRadius:BorderRadius.circular(10)
                                          ),
                                          child: Icon(Icons.directions,
                                              size: btnSize),
                                        ),
                                      ),
                                      SizedBox(
                                        height: 1,
                                      ),
                                      GestureDetector(
                                        onTap: () {
                                          showModalBottomSheet<void>(
                                            context: context,
                                            builder: (BuildContext context) {
                                              return Container(
                                                decoration: const BoxDecoration(
                                                    color: Colors.white,
                                                    borderRadius:
                                                        BorderRadius.only(
                                                            topLeft: Radius
                                                                .circular(50),
                                                            topRight:
                                                                Radius.circular(
                                                                    50))),
                                                child: Padding(
                                                  padding: const EdgeInsets.all(
                                                      10.0),
                                                  child: SingleChildScrollView(
                                                    child: Column(
                                                      crossAxisAlignment:
                                                          CrossAxisAlignment
                                                              .start,
                                                      children: [
                                                        TextButton(
                                                            onPressed:
                                                                () async {
                                                              final SharedPreferences
                                                                  sharedPreferences =
                                                                  await SharedPreferences
                                                                      .getInstance();
                                                              sharedPreferences
                                                                  .setDouble(
                                                                      'lat',
                                                                      19.093099);
                                                              sharedPreferences
                                                                  .setDouble(
                                                                      'long',
                                                                      72.856952);
                                                              sharedPreferences
                                                                  .setString(
                                                                      'styleString',
                                                                      'mapbox://styles/merrillgonsalves/cl5ez27io005p14rz5aqp8234');
                                                              Get.off(
                                                                  Loading());
                                                              // Navigator.pop(
                                                              //     context);
                                                              print(
                                                                  "TAPPED IN LEVEL 0");
                                                              controller
                                                                  .dispose();
                                                            },
                                                            child: Text(
                                                                "Terminal 1")),
                                                        TextButton(
                                                            onPressed:
                                                                () async {
                                                              final SharedPreferences
                                                                  sharedPreferences =
                                                                  await SharedPreferences
                                                                      .getInstance();
                                                              sharedPreferences
                                                                  .setDouble(
                                                                      'lat',
                                                                      19.098519);
                                                              sharedPreferences
                                                                  .setDouble(
                                                                      'long',
                                                                      72.874318);
                                                              sharedPreferences
                                                                  .setString(
                                                                      'styleString',
                                                                      'mapbox://styles/merrillgonsalves/cl508fw8s000u15rsht67q9tx');
                                                              Get.off(
                                                                  Loading());
                                                              // Navigator.pop(
                                                              //     context);
                                                              controller
                                                                  .dispose();
                                                              print(
                                                                  "TAPPED TERMINAL 2");
                                                            },
                                                            child: Text(
                                                                "Terminal 2")),
                                                      ],
                                                    ),
                                                  ),
                                                ),
                                              );
                                            },
                                          );
                                        },
                                        child: Container(
                                          padding: EdgeInsets.all(btnPadding),
                                          decoration: BoxDecoration(
                                              color: Colors.white,
                                              borderRadius: BorderRadius.only(
                                                  bottomLeft:
                                                      Radius.circular(7),
                                                  bottomRight:
                                                      Radius.circular(7))),
                                          child: Icon(Icons.airplane_ticket,
                                              size: btnSize),
                                        ),
                                      ),
                                    ],
                                  ),
                                ],
                              ),
                            ),
                          ],
                        ),
                        Column(
                          children: [
                            SizedBox(height: 5),
                            Container(
                              margin: EdgeInsets.symmetric(horizontal: 20),
                              padding: EdgeInsets.symmetric(vertical: 0),
                              child: TextFormField(
                                scrollPadding: EdgeInsets.zero,
                                decoration: InputDecoration(
                                    isDense: true,
                                    contentPadding: EdgeInsets.all(0.0),
                                    prefixIcon: const Icon(
                                      Icons.search,
                                    ),
                                    suffixIcon: const Icon(Icons.directions),
                                    hintText: "Search",
                                    hintStyle: TextStyle(
                                        fontWeight: FontWeight.bold,
                                        fontSize: 15),
                                    border: OutlineInputBorder(
                                      borderRadius: BorderRadius.circular(40),
                                    )),
                              ),
                            ),
                            SizedBox(height: 10),
                            Row(
                              mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                              children: [],
                            ),
                            SizedBox(height: 10),
                            SizedBox(
                              height: myHeight - 48,
                              child: SingleChildScrollView(
                                padding: EdgeInsets.symmetric(horizontal: 20),
                                child: Column(
                                  mainAxisAlignment: MainAxisAlignment.start,
                                  crossAxisAlignment: CrossAxisAlignment.start,
                                  children: [
                                    // SizedBox(height: 5),
                                    Text(
                                      "Explore",
                                      style: TextStyle(
                                          fontSize: fontSize,
                                          fontStyle: FontStyle.italic),
                                    ),
                                    SizedBox(height: 15),
                                    Row(
                                        mainAxisAlignment:
                                            MainAxisAlignment.spaceAround,
                                        children: [
                                          Column(
                                            mainAxisAlignment:
                                                MainAxisAlignment.start,
                                            crossAxisAlignment:
                                                CrossAxisAlignment.start,
                                            children: [
                                              Row(
                                                mainAxisAlignment:
                                                    MainAxisAlignment
                                                        .spaceBetween,
                                                children: [
                                                  Image.asset(
                                                    // "assets/symbols/Oval.png",
                                                    "assets/images/restro2.png",
                                                    // "assets/symbols/neww.png",
                                                    height: 30,
                                                    width: 30,
                                                  ),
                                                  SizedBox(width: 10),
                                                  Text(
                                                    "Restaurants",
                                                    style: TextStyle(
                                                        fontSize: fontSize),
                                                  )
                                                ],
                                              ),
                                              SizedBox(
                                                height: 15,
                                              ),
                                              Row(
                                                children: [
                                                  Image.asset(
                                                    "assets/images/shopping.png",
                                                    height: 35,
                                                    width: 35,
                                                  ),
                                                  SizedBox(width: 10),
                                                  Text(
                                                    "Shopping",
                                                    style: TextStyle(
                                                        fontSize: fontSize),
                                                  )
                                                ],
                                              )
                                            ],
                                          ),
                                          Column(
                                            crossAxisAlignment:
                                                CrossAxisAlignment.start,
                                            children: [
                                              Row(
                                                children: [
                                                  Image.asset(
                                                    "assets/images/facilities.png",
                                                    height: 35,
                                                    width: 35,
                                                  ),
                                                  SizedBox(width: 10),
                                                  Text(
                                                    "Facilities",
                                                    style: TextStyle(
                                                        fontSize: fontSize),
                                                  )
                                                ],
                                              ),
                                              SizedBox(
                                                height: 15,
                                              ),
                                              Row(
                                                children: [
                                                  Image.asset(
                                                    "assets/images/utilities.png",
                                                    height: 35,
                                                    width: 35,
                                                  ),
                                                  SizedBox(width: 10),
                                                  Text(
                                                    "Utilities",
                                                    style: TextStyle(
                                                        fontSize: fontSize),
                                                  )
                                                ],
                                              )
                                            ],
                                          )
                                        ]),
                                  ],
                                ),
                              ),
                            ),
                          ],
                        )
                      ],
                    ),
            ),
          ],
        ),
      )),
    );
  }
}
